# -*- coding: utf-8 -*-

"""
Selenium PageModel library
~~~~~~~~~~~~~~~~~~~~~~~~~~

:copyright: (c) 2017 by Peter Salas.
:license: Apache 2.0, see LICENSE for more details.
"""

__title__ = 'seleniumpm'
__version__ = '2.4.2'
__build__ = 0x021000
__author__ = 'Peter Salas'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2017 Peter Salas'
